#########################################################
####     Luhmann - R fr Einsteiger - 4. Auflage    #####
####              Kapitel 11 - Graphiken            #####
#########################################################


# Beispieldaten laden 
setwd("D:/Ordner 1/Ordner 2")
load("erstis.RData")

attach(erstis)

#### Abschnitt 11.1 ####

# Sulendiagramm fr absolute Hufigkeiten
barplot(table(wohnort.alt))

# Sulendiagramm fr relative Hufigkeiten
barplot(prop.table(table(wohnort.alt)))

# Balkendiagramm
barplot(table(wohnort.alt), horiz=TRUE, las=1)

# Gestapeltes Sulendiagramm
barplot(table(wohnort.alt, geschl), legend=TRUE)

# Gruppiertes Sulendiagramm
barplot(table(wohnort.alt, geschl), legend=TRUE, beside=TRUE)

# Kreisdiagramm
pie(table(wohnort.alt))


#### Abschnitt 11.2 ####

# Sulendiagramm
barplot(lz.1) 

# Histogramm
hist(lz.1)

# Anzahl der Sulen anpassen
hist(lz.1, breaks=20)

# Histogramm mit Normalverteilungskurve
hist(lz.1, breaks=20)
mittelwert <- mean(lz.1, na.rm=TRUE)
sd <- sd(lz.1, na.rm=TRUE)
curve(dnorm(x, mittelwert, sd)*length(lz.1), add = TRUE)

# Histogramm mit Dichtewerten
hist(lz.1, freq = FALSE)
curve(dnorm(x, mittelwert, sd), add = TRUE)

# Kerndichte-Diagramm
plot(density(lz.1, na.rm = TRUE))
curve(dnorm(x, mittelwert, sd), add = TRUE, lty = 2)

# Einfacher Boxplot
boxplot(alter)

# Boxplots fr verschiedene abhngige Variablen
boxplot(data.frame(gs.1, ru.1, wm.1))


# Gruppierte Boxplots
boxplot(alter ~ geschl)

# Identifikation von Ausreiern
identify(geschl, alter, labels = code)

# Sulendiagramm fr Mittelwerte: 2 Gruppen
barplot(tapply(neuro, geschl, mean, na.rm=TRUE))

# Sulendiagramm fr Mittelwerte: 4 Gruppen
barplot(tapply(neuro, data.frame(geschl, berlin), mean, na.rm=TRUE), 
	ylim = c(0,5), beside=TRUE, legend=TRUE)

# Fehlerbalkendiagramm: gplots-Paket installieren und laden
install.packages("gplots")
library(gplots)

# Fehlerbalkendiagramm mit der plotmeans-Funktion
plotmeans(neuro ~ geschl)

# Fehlerbalkendiagramm mit 99%-Konfidenzintervall
plotmeans(neuro ~ geschl, p = .99)

# Fehlerbalkendiagramm mit der error.bars-Funktion
library(psych)
auswahl <- na.omit(data.frame(lz.1, lz.2))

error.bars(auswahl, within = TRUE)
error.bars(auswahl, within = TRUE, eyes = FALSE)
error.bars(auswahl, within = TRUE, bars = T)


# Fehlerbalkendiagramm mit der error.bars.by-Funktion
error.bars.by(data.frame(neuro), geschl, by.var = TRUE, eyes = FALSE)


### Fehlerbalkendiagramm manuell erstellen

# Deskriptive Statistiken
d <- describeBy(neuro, wohnort.alt, mat = TRUE)

# Barplot erstellen und Koordinaten speichern
coord <- barplot(d$mean, ylim = c(1,5), xpd = FALSE, names.arg = d$group1)
coord 

# Horizontale Linie hinzufgen
abline(h = 1)

# Einen Fehlerbalken hinzufgen
arrows(coord[1], d$mean[1] - d$se[1], 
	coord[1], d$mean[1] + d$se[1],
	code = 3, angle = 90, length = .1)

# Alle Fehlerbalken auf einmal hinzufgen
for(i in 1:nrow(d)) {
	arrows(coord[i], d$mean[i]-d$se[i], 
	coord[i], d$mean[i]+d$se[i],
	code = 3, angle = 90, length = .1)
}

# Q-Q-Plot in der R-Basisversion
qqnorm(lz.1)

# Q-Q-Plot im car-Paket
library(car)
qqPlot(lz.1)


#### Abschnitt 11.3 ####

# Streudiagramm
plot(neuro, lz.1)


# Streudiagramm mit Lowess-Kurve
auswahl <- na.omit(data.frame(neuro, lz.1))
plot(auswahl$lz.1 ~ auswahl$neuro)
lines(lowess(auswahl$lz.1 ~ auswahl$neuro), lwd = 2)

# Regressionsgerade ergnzen
abline(lm(lz.1 ~ neuro), lwd = 2)


# Einzelne Werte identifizieren
identify(neuro, lz.1, labels=code)

# Streudiagramm-Matrix
plot(data.frame(neuro, gewiss, extra))
pairs.panels(data.frame(neuro, gewiss, extra))


#### Abschnitt 11.4 ####

# plot mit Vektor
plot(lz.1)

# plot mit Faktor
plot(wohnort.alt)

# plot mit zwei Vektoren
plot(lz.1, neuro)

# plot mit einem Faktor und einem Vektor
plot(wohnort.alt, lz.1)

# plot mit zwei Faktoren
plot(wohnort.alt, geschl)

# Indexplot mit type = "l" und type = "b"
plot(lz.1, type = "l")
plot(lz.1, type = "b")

# Streudiagramm mit type = "l" und type = "b"
plot(lz.1, neuro, type = "l")
plot(lz.1, neuro, type = "b")



#### Abschnitt 11.5 ####

# Standardeinstellungen auflisten
par() 

# Linientyp ndern und zurcksetzen
par(lty="dotted")
par(lty="solid")

# Punkte verndern
plot(neuro, gewiss, pch = 16)
plot(neuro, gewiss, pch = "A")
plot(neuro, gewiss, pch = 2, cex = 2)

# Linien verndern
plot(neuro, gewiss)
abline(h = 3, lty = 2)

plot(neuro, gewiss)
abline(h = 3, lty = 2, lwd = 2)

# Achsenbeschriftung
plot(neuro,lz.1, las=1)
plot(neuro,lz.1, xlab="Lebenszufriedenheit",ylab="Neurotizismus")

# Achsenskalierung
plot(neuro, lz.1, xlim=c(1,5), ylim=c(7,35))

# Titel und Untertitel
pie(table(geschl), main="Beispiel fr ein unntiges Tortendiagramm", sub="Ich habe Hunger")

# Schriftart und Schriftschnitt
barplot(table(wohnort.alt, geschl), family="serif") 
barplot(table(wohnort.alt, geschl), font = 2) 

# Schriftgre
plot(neuro, lz.1, main = "Neues Diagramm", cex.main = .8, 
	font.main = 3, col.lab = 2, col.axis = 3)

# Farben
colors()
barplot(table(wohnort.alt,geschl), beside=TRUE, 
	col=c("tomato4","chocolate1","ghostwhite", "cornflowerblue"))

# Legende
barplot(table(wohnort.alt,geschl), beside=TRUE, 
col=c("tomato4","chocolate1","ghostwhite", "cornflowerblue"))

legend("topright", 
 c("Alte Bundeslnder", "Neue Bundeslnder","Berlin", 
 "Ausland"), 
 fill=c("tomato4", "chocolate1", "ghostwhite", 
 "cornflowerblue"))

# Koordinaten
locator()







