############################################################
####      Luhmann - R fr Einsteiger - 4. Auflage      #####
####       Kapitel 20 - Strukturgleichungsmodelle      #####
############################################################


# Beispieldaten laden 
setwd("D:/Ordner 1/Ordner 2")

load("erstis.RData")



#### Abschnitt 20.1 ####

# lavaan laden
library(lavaan)

# Modell spezifizieren
reg.txt = 'lz.1 ~ neuro + extra'

# Modell schaetzen
reg.fit = sem(reg.txt, data = erstis)

# Ausgabe anfordern
summary(reg.fit)

# Ausgabe mit standardisierten Regressionskoeffizienten
summary(reg.fit, standardized = TRUE)


#### Abschnitt 20.2 ####

# Modell spezifizieren
med1.txt = 'prok ~ gewiss
           lz.1 ~ prok + gewiss'

# Modell schaetzen
med1.fit = sem(med1.txt, data = erstis)

# Ausgabe anfordern
summary(med1.fit)


# Modell mit indirekten Effekten spezifizieren

med2.txt = 'prok ~ a*gewiss     # a-Pfad benennen
            lz.1 ~ b*prok + c*gewiss      # b-Pfad und c-Pfad benennen
            indirekt := a*b       # Indirekten Effekt definieren
            total := c + (a*b) '  # Totalen Effekt definieren

# Modell schaetzen mit Bootstrap
med2.fit = sem(med2.txt, data = erstis, se = "bootstrap")

# Ausgabe anfordern
summary(med2.fit)

# Parameter mit bias-korrigierten Konfidenzintervallen anfordern 
parameterEstimates(med2.fit, ci = T, boot.ci.type = "bca.simple")

#### Abschnitt 20.3 ####

### Einfaktorielles MOdell

# Modell spezifizieren
cfa.1.txt = 'f =~ lz13 + lz14 + lz15 + lz16 + lz17'

# Modell schaetzen
cfa.1.fit = cfa(cfa.1.txt, data = erstis)

# Ausgabe anfordern
summary(cfa.1.fit, fit = T)

# Modell schaetzen
cfa.1b.fit = cfa(cfa.1b.txt, data = erstis)

# Ausgabe anfordern
summary(cfa.1b.fit, fit = T)


### Zweifaktorielles Modell

# Modell spezifizieren
cfa.2.txt = 'f1 =~ lz13 + lz14 + lz15
             f2 =~ lz16 + lz17'

# Modell schaetzen
cfa.2.fit = cfa(cfa.2.txt, data = erstis)

# Ausgabe anfordern
anova(cfa.1.fit, cfa.2.fit)


#### Abschnitt 20.4 ####

# Paket fuer Pfaddiagramme laden
library(semPlot)


# Modell spezifizieren
sem.txt = 'zuf =~ zuf.inh.1 + zuf.bed.1 + zuf.bel.1  # Messmodell
          lz =~ lz13 + lz14 + lz15
           lz ~ zuf '   # Strukturmodell


# Modell schaetzen
sem.fit = sem(sem.txt, data = erstis)

# Ausgabe anfordern inkl. Fit-Indices
summary(sem.fit, fit = T)

# Pfaddiagramm erstellen
semPaths(sem.fit)

# Pfaddiagramm modifizieren
semPaths(sem.fit, whatLabels = "est", layout = "spring", layoutSplit = T, rotation = 2)
