############################################################
####      Luhmann - R fr Einsteiger - 4. Auflage      #####
####           Kapitel 21 - Mehrebenenanalyse          #####
############################################################


# Beispieldaten laden 
setwd("D:/Ordner 1/Ordner 2")

load("kultur.RData")


# Paket lme4 laden
library("lme4")


#### Abschnitt 21.1 ####

# Nullmodell spezifizieren
modell.1 = lmer(lezu ~ 1 + (1 | nation), data = kultur)

# Ausgabe
summary(modell.1)

# Intraklassenkorrelation
VarCorr(modell.1)$nation[1,1] / var(kultur$lezu, na.rm = T)


#### Abschnitt 21.2 ####

# Random Intercept-Modell spezifizieren
modell.2 = lmer(lezu ~ pa + (1 | nation), data = kultur)

# Ausgabe anfordern
summary(modell.2)

# Modellvergleich mit anova
anova(modell.1, modell.2)

# p-Werte mit Anova (car) anfordern
library(car)
Anova(modell.2)

# p-Werte mit lmerTest anfordern
library(lmerTest)
modell.2 = lmer(lezu ~ pa + (1 | nation), data = kultur)

summary(modell.2)
summary(modell.2, ddf="Kenward-Roger")
anova(modell.2)
anova(modell.2, ddf="Kenward-Roger")

# Zentrierung am Gesamtmittelwert
kultur$pa.zen.ges = scale(kultur$pa, scale = F)

# Zentrierung am Gruppenmittelwert: Gruppenmittelwerte berechnen
kultur$pa.gm = ave(kultur$pa, kultur$nation, FUN = function(x) mean(x, na.rm = T))

# Zentrierung am Gruppenmittelwert: Gruppenmittelwert subtrahieren
kultur$pa.zen.gm = kultur$pa - kultur$pa.gm

# Modell 2 mit zentriertem Prdiktor
modell.2a = lmer(lezu ~ pa.zen.gm + (1 | nation), data = kultur)



#### Abschnitt 21.3 ####

# Random-Slopes-Modell spezifizieren und Ausgabe anfordern

modell.3 = lmer(lezu ~ pa.zen.gm + (pa.zen.gm | nation), data = kultur)
summary(modell.3)

# Vergleich mit Random-Intercept-Modell
anova(modell.2a, modell.3)

# Random Slopes darstellen
library(lattice)
dotplot(ranef(modell.3, condVar = T))


#### Abschnitt 21.4 ####

# Ebene-2-Prdiktor zentrieren
kultur$gdp.zen = scale(kultur$gdp, scale = F)


# Modell mit Ebene-2-Prdiktor (ohne Interaktion)
modell.4 = lmer(lezu ~ pa.zen.gm + gdp.zen + (pa.zen.gm | nation), data = kultur)
summary(modell.4)

# Modell mit Ebene 2-Prdiktor (mit Interaktion)
modell.5 = lmer(lezu ~ pa.zen.gm * gdp.zen + (pa.zen.gm | nation), data = kultur)
summary(modell.5)
