#########################################################
####     Luhmann - R fr Einsteiger - 3. Auflage    #####
#### Kapitel 9 - Univariate deskriptive Statistiken #####
#########################################################


# Beispieldaten laden 
setwd("D:/Ordner 1/Ordner 2")
load("erstis.RData")

attach(erstis)


#### Abschnitt 9.1 ####

# Absolute Hufigkeiten fr wohnort.alt 
table(wohnort.alt)

# Hufigkeitstabelle aufsteigend sortieren
sort(table(wohnort.alt))

# Hufigkeitstabelle absteigend sortieren
sort(table(wohnort.alt), decreasing = TRUE)

# Relative Hufigkeiten 
prop.table(table(wohnort.alt))

# Prozentwerte 
100*prop.table(table(wohnort.alt))

# Auf ganze Zahlen gerundete Prozentwerte
round(100*prop.table(table(wohnort.alt)))

# Auf eine Nachkommastelle gerundete Prozentwerte
round(100*prop.table(table(wohnort.alt)), 1)

# Kumulierte Hufigkeiten
cumsum(100*prop.table(table(wohnort.alt)))

# Integration der Werte in einer Tabelle
absolut <- table(wohnort.alt)
relativ <- prop.table(absolut)
prozent <- 100*relativ
kumuliert <- cumsum(prozent)
haeufigkeiten <- cbind(absolut, relativ, prozent, kumuliert)
round(haeufigkeiten,2)


#### Abschnitt 9.2 ####

# Hufigkeitstabelle (Wiederholung)
table(wohnort.alt)

# Modalwert
which.max(table(wohnort.alt))

# Maximale absolute Hufigkeit
max(table(wohnort.alt))

# Schritte zur Berechnung des relativen Informationsgehalts
relhaeufig <- prop.table(table(wohnort.alt))
term2 <- relhaeufig*log(relhaeufig)
summe <- sum(term2)
kehrwert <- -1/log(4)
summe*kehrwert

# Alle Schritte in einem einzigen Befehl
(-1/log(4)) * sum(prop.table(table(wohnort.alt)) * 
	log(prop.table(table(wohnort.alt))))


#### Abschnitt 9.3 ####

# CTT-Paket installieren und laden

install.packages("CTT")
library(CTT)

# score.transform-Funktion durchfhren und Ergebnis speichern
alter.transf <- score.transform(alter)

# Prozentrnge ausgeben lassen
alter.transf$p.scores

# Prozentrnge als eigene Variable speichern
erstis$prozentrang.alter <- alter.transf$p.scores

# Prozentrang fr einzelne Person ber Index-Funktion anfordern
erstis[code == 28, c("alter", "prozentrang.alter")]

# Median
median(stim1)

# Median ohne fehlende Werte
median(stim1, na.rm=TRUE)

# Wertebereich/Range
range(stim1, na.rm=TRUE)

# Spannweite des Wertebereichs
diff(range(stim1, na.rm=TRUE))

# Quartile
quantile(stim1,na.rm=TRUE)

# Zahlensequenzen anfordern
seq(0, .5, .1)

# Dezile
quantile(stim1, na.rm=TRUE, probs = seq(0, 1, 0.1))


#### Abschnitt 9.4 ####

# Mittelwert
mean(extra, na.rm=TRUE)

# Gerundeter Mittelwert
round(mean(extra, na.rm=TRUE), 2)

# Standardabweichung
sd(extra, na.rm=TRUE)

# Gerundete Standardabweichung
round(sd(extra, na.rm=TRUE), 2)

# Varianz
var(extra, na.rm=TRUE)

# QuantPsyc-Paket installieren und laden
install.packages("QuantPsyc")
library(QuantPsyc)

# Schiefe und Exzess
norm(extra)

# Die describe-Funktion
install.packages("psych")
library(psych)

describe(data.frame(gewiss, extra))



#### Abschnitt 9.5 ####

# summary-Funktion fr Faktoren
summary(wohnort.alt)

# summary-Funktion fr Vektoren
summary(extra)

# summary-Funktion fr ganzen Data Frame
summary(erstis)

# summary-Funktion fr ausgewhlte Variablen
summary(data.frame(geschl, gewiss, vertraeg))


#### Abschnitt 9.6 ####

# Gruppenvergleiche mit der describeBy-Funktion
library(psych)
describeBy(extra, geschl)

# Darstellung in Tabellenform
describeBy(extra, geschl, mat = TRUE)

# Gruppenvergleiche mit mehreren Faktoren
describeBy(extra, list(geschl, berlin), mat = T)

# Gruppenvergleiche: Mittelwerte von extra fr Frauen und Mnner
tapply(extra, geschl, mean, na.rm=TRUE)

# Gruppenvergleiche: summary for extra 
tapply(extra, geschl, summary)

# Mittelwertsvergleiche fr mehrere Faktoren: Mittelwerte
tapply(extra, data.frame(geschl, berlin), mean, na.rm=TRUE)
